Βπ’ calcucalc π
A Rust library for doing general-purpose calculus.
Βπ± Getting Started
The goal of this project is to provide a simple and easy-to-use library for doing calculus operations.
Βπ¦ Prerequisites
You will need to have Rust and the Cargo package manager installed on your machine. You can install them by following the instructions on the official Rust lang site.
Βπ₯οΈ Installing
To install this library, add the following to your Cargo.toml file:
[dependencies]
calcucalc = "VERSION_GOES_HERE"It is recommended to use the latest version. You can find the latest version on this libraryβs crates.io page.
Βπ οΈ Usage
This documentation provides examples of how to use the library. Just navigate to the item you want to learn more about, and the description and examples will be there.
Overall, this library relies heavily on the use of the f64 type for the sake of flexibility and generality.
ModulesΒ
StructsΒ
- Monomial
- A monomial is a product of a coefficient and an exponent of x.
For example, in the monomial
3x^2, the coefficient is3and the exponent of x is2. The monomial3x^2can be represented as a struct with the coefficient3and the exponent2. Using the calcucalc library, this monomial would be represented in this way - Polynomial
- A polynomial is a sum of monomials.
For example, the polynomial
3x^2 + 2x + 1can be represented as a vector of monomials, which is how this library represents it.